@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.243 2009/02/23 04:27:50 Martin Exp $
+# $Id: Ebay.pm,v 2.249 2009-08-30 23:43:44 Martin Exp $
 
 =head1 NAME
 
@@ -156,7 +156,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.243 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.249 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -266,7 +266,7 @@ sub preprocess_results_page
   {
   my $self = shift;
   my $sPage = shift;
-  if (0)
+  if (25 < $self->{_debug})
     {
     # print STDERR Dumper($self->{response});
     # For debugging:
@@ -411,6 +411,10 @@ sub _parse_price
   my $currency = $self->_currency_pattern;
   my $W = $self->whitespace_pattern;
   $iPrice =~ s!($currency)$W*($currency)!$1 (Buy-It-Now for $2)!;
+  if ($iPrice =~ s/Free\s+Shipping//i)
+    {
+    $hit->shipping('free');
+    } # if
   $hit->bid_amount($iPrice);
   return 1;
   } # _parse_price
@@ -436,6 +440,7 @@ sub _parse_bids
       return 0;
       # There is a separate backend for searching Auction items!
       } # if
+    $iBids =  1 if ($oTDbids->as_text =~ m/SOLD/i);
     $iBids = $1 if ($oTDbids->as_text =~ m/(\d+)/);
     my $W = $self->whitespace_pattern;
     if (
@@ -501,15 +506,28 @@ sub _parse_enddate
     $sDateTemp = $s = $oTDdate;
     }
   print STDERR " DDD   TDdate ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
-  if (ref($oTDdate) && ($oTDdate->attr('class') !~ m'\b(ebcTim|time)\b'))
+  if (ref($oTDdate))
     {
+    if ($oTDdate->attr('class') !~ m/\b(ebcTim|time)\b/)
+      {
+      print STDERR " DDD parse_enddate: oTDdate wrong class\n";
+      # If we see this, we probably were searching for Buy-It-Now items
+      # but we ran off the bottom of the item list and ran into the list
+      # of Store items.
+      return 0;
+      # There is a separate backend for searching Store items!
+      } # if
+    } # if
+  print STDERR " DDD   raw    sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
+  if ($sDateTemp =~ m/---/)
+    {
+    print STDERR qq{ DDD parse_enddate: oTDdate is "---"\n};
     # If we see this, we probably were searching for Buy-It-Now items
     # but we ran off the bottom of the item list and ran into the list
     # of Store items.
     return 0;
     # There is a separate backend for searching Store items!
     } # if
-  print STDERR " DDD   raw    sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
   # I don't know why there are sometimes weird characters in there:
   $sDateTemp =~ s!&Acirc;!!g;
   $sDateTemp =~ s!!!g;
@@ -1114,7 +1132,7 @@ sub _columns
   {
   my $self = shift;
   # This is for basic USA eBay:
-  return qw( paypal bids price shipping enddate );
+  return qw( paypal bids price enddate );
   } # _columns
 
 1;
@@ -1145,6 +1163,8 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 LICENSE
 
+Copyright (C) 1998-2009 Martin 'Kingpin' Thurn
+
 This software is released under the same license as Perl itself.
 
 =cut
